@@ -1,4 +1,4 @@
-# Copyright 2013 Jeffrey Kegler
+# Copyright 2015 Jeffrey Kegler
 # This file is part of Marpa::R2.  Marpa::R2 is free software: you can
 # redistribute it and/or modify it under the terms of the GNU Lesser
 # General Public License as published by the Free Software Foundation,
@@ -43,9 +43,14 @@ sub quotearg {
 
 sub run_command {
     my (@args)     = @_;
+
+    my $blib = $ENV{MARPA_TEST_BLIB};
     my $current_wd = Cwd::getcwd();
-    my $blib_arg   = '-Mblib=' . quotearg($current_wd);
-    my $command = join q{ }, $EXECUTABLE_NAME, $blib_arg, map { quotearg($_) } @args;
+    $blib //= $current_wd;
+    my $blib_arg   = '-Mblib=' . quotearg($blib);
+
+    # my $command = join q{ }, $EXECUTABLE_NAME, $blib_arg, map { quotearg($_) } @args;
+    my $command = join q{ }, $EXECUTABLE_NAME, map { quotearg($_) } @args;
 
     ## no critic (InputOutput::ProhibitBacktickOperators)
     my $stdout = `$command`;
@@ -76,15 +81,15 @@ sub load_or_skip_all {
     use lib 'config';
     $eval_result = eval { require Marpa::R2::Config; 1 };
     if ( !$eval_result ) {
-	Test::More::plan tests => 1;
-	Test::More::diag($EVAL_ERROR);
-	Test::More::fail("Could not load Marpa::R2::Config\n");
+        Test::More::plan tests => 1;
+        Test::More::diag($EVAL_ERROR);
+        Test::More::fail("Could not load Marpa::R2::Config\n");
         exit 0;
     } ## end if ( !$eval_result )
     my $version_wanted = $Marpa::R2::VERSION_FOR_CONFIG{$module_name};
     if ( not defined $version_wanted ) {
-	Test::More::plan tests => 1;
-	Test::More::fail("$module_name is not known to Marpa::R2");
+        Test::More::plan tests => 1;
+        Test::More::fail("$module_name is not known to Marpa::R2");
         exit 0;
     }
     my $module_version = eval q{$} . $module_name . '::VERSION';
@@ -97,3 +102,5 @@ sub load_or_skip_all {
 } ## end sub load_or_skip_all
 
 1;
+
+# vim: set expandtab shiftwidth=4:
